@@ -101,6 +101,7 @@ class HttpApiClient(BaseApiClient):
         Raises the appropriate exceptions when necessary; otherwise, returns the
         response.
         """
+
         if not str(response.status_code).startswith('2'):
             raise BinanceChainAPIException(response, response.status_code)
         try:
@@ -336,6 +337,7 @@ class HttpApiClient(BaseApiClient):
             # new order example
             # construct the message
             new_order_msg = NewOrderMsg(
+                wallet=wallet,
                 symbol="ANN-457_BNB",
                 time_in_force=TimeInForce.GTE,
                 order_type=OrderType.LIMIT,
@@ -344,14 +346,15 @@ class HttpApiClient(BaseApiClient):
                 quantity=Decimal(12)
             )
             # then broadcast it
-            res = client.broadcast_msg(new_order_msg, wallet)
+            res = client.broadcast_msg(new_order_msg, sync=True)
 
             # cancel order example
             cancel_order_msg = CancelOrderMsg(
+                wallet=wallet,
                 order_id="09F8B32D33CBE2B546088620CBEBC1FF80F9BE001ACF42762B0BBFF0A729CE3",
                 symbol='ANN-457_BNB',
             )
-            res = client.broadcast_msg(cancel_order_msg, wallet)
+            res = client.broadcast_msg(cancel_order_msg, sync=True)
 
         :return: API Response
 
@@ -366,8 +369,6 @@ class HttpApiClient(BaseApiClient):
         msg.wallet.initialise_wallet()
         data = msg.to_hex_data()
 
-        logging.debug(f'data:{data}')
-
         req_path = 'broadcast'
         if sync:
             req_path += f'?sync=1'
@@ -376,6 +377,53 @@ class HttpApiClient(BaseApiClient):
         msg.wallet.increment_account_sequence()
         return res
 
+    def broadcast_hex_msg(self, hex_msg: str, sync: bool = False):
+        """Broadcast a message in hex format
+
+        This may have been generated internally or by a signing service
+
+        It is up to the user to keep track of the account sequence when using this method
+
+        https://binance-chain.github.io/api-reference/dex-api/paths.html#apiv1broadcast
+
+        :param hex_msg: signed message string
+        :param sync: Synchronous broadcast (wait for DeliverTx)?
+
+        .. code:: python
+
+            # new order example
+            # construct the message
+            new_order_msg = NewOrderMsg(
+                symbol="ANN-457_BNB",
+                time_in_force=TimeInForce.GTE,
+                order_type=OrderType.LIMIT,
+                side=OrderSide.BUY,
+                price=Decimal(0.000396000),
+                quantity=Decimal(12)
+            )
+
+            # then broadcast it
+            res = client.broadcast_hex_msg(hex_msg=new_order_msg.to_hex_data(), sync=True)
+
+            #
+
+            # cancel order example
+            cancel_order_msg = CancelOrderMsg(
+                order_id="09F8B32D33CBE2B546088620CBEBC1FF80F9BE001ACF42762B0BBFF0A729CE3",
+                symbol='ANN-457_BNB',
+            )
+            res = client.broadcast_msg(cancel_order_msg.to_hex_data(), sync=True)
+
+        :return: API Response
+
+        """
+        req_path = 'broadcast'
+        if sync:
+            req_path += f'?sync=1'
+
+        res = self._post(req_path, data=hex_msg)
+        return res
+
     def get_klines(self, symbol: str, interval: KlineInterval, limit: Optional[int] = 300,
                    start_time: Optional[int] = None, end_time: Optional[int] = None):
         """Gets candlestick/kline bars for a symbol. Bars are uniquely identified by their open time
@@ -397,7 +445,7 @@ class HttpApiClient(BaseApiClient):
         """
         data = {
             'symbol': symbol,
-            'interval': interval
+            'interval': interval.value
         }
         if limit is not None:
             data['limit'] = limit
@@ -440,9 +488,9 @@ class HttpApiClient(BaseApiClient):
         if symbol is not None:
             data['symbol'] = symbol
         if status is not None:
-            data['status'] = status
+            data['status'] = status.value
         if side is not None:
-            data['side'] = side
+            data['side'] = side.value
         if offset is not None:
             data['offset'] = offset
         if limit is not None:
@@ -565,7 +613,7 @@ class HttpApiClient(BaseApiClient):
         if symbol is not None:
             data['symbol'] = symbol
         if side is not None:
-            data['side'] = side
+            data['side'] = side.value
         if quote_asset is not None:
             data['quoteAsset'] = quote_asset
         if buyer_order_id is not None:
@@ -621,23 +669,61 @@ class HttpApiClient(BaseApiClient):
         if symbol is not None:
             data['symbol'] = symbol
         if side is not None:
-            data['side'] = side
+            data['side'] = side.value
         if tx_asset is not None:
             data['txAsset'] = tx_asset
         if tx_type is not None:
-            data['txType'] = tx_type
+            data['txType'] = tx_type.value
         if height is not None:
             data['blockHeight'] = height
         if offset is not None:
             data['offset'] = offset
         if limit is not None:
             data['limit'] = limit
+        if start_time is not None:
+            data['startTime'] = start_time
+        if end_time is not None:
+            data['endTime'] = end_time
+
+        return self._get("transactions", data=data)
+
+    def get_block_exchange_fee(
+        self, address: Optional[str] = None, offset: Optional[int] = 0, total: Optional[int] = 0,
+        limit: Optional[int] = 500, start_time: Optional[int] = None, end_time: Optional[int] = None
+    ):
+        """Trading fee of the address grouped by block
+
+        https://docs.binance.org/api-reference/dex-api/paths.html#apiv1block-exchange-fee
+
+        :param address:
+        :param offset:
+        :param limit:
+        :param start_time:
+        :param end_time:
+        :param total:
+
+        .. code:: python
+
+            transactions = client.get_transactions('')
+
+        :return: API Response
+
+        """
+        data = {}
+        if address is not None:
+            data['address'] = address
+        if offset is not None:
+            data['offset'] = offset
+        if limit is not None:
+            data['limit'] = limit
         if start_time is not None:
             data['start'] = start_time
         if end_time is not None:
             data['end'] = end_time
+        if total is not None:
+            data['total'] = total
 
-        return self._get("transactions", data=data)
+        return self._get("block-exchange-fee", data=data)
 
 
 class AsyncHttpApiClient(BaseApiClient):
@@ -787,11 +873,20 @@ class AsyncHttpApiClient(BaseApiClient):
         return res
     broadcast_msg.__doc__ = HttpApiClient.broadcast_msg.__doc__
 
+    async def broadcast_hex_msg(self, hex_msg: str, sync: bool = False):
+        req_path = 'broadcast'
+        if sync:
+            req_path += f'?sync=1'
+
+        res = await self._post(req_path, data=hex_msg)
+        return res
+    broadcast_msg.__doc__ = HttpApiClient.broadcast_msg.__doc__
+
     async def get_klines(self, symbol: str, interval: KlineInterval, limit: Optional[int] = 300,
                          start_time: Optional[int] = None, end_time: Optional[int] = None):
         data = {
             'symbol': symbol,
-            'interval': interval
+            'interval': interval.value
         }
         if limit is not None:
             data['limit'] = limit
@@ -814,7 +909,7 @@ class AsyncHttpApiClient(BaseApiClient):
         if symbol is not None:
             data['symbol'] = symbol
         if status is not None:
-            data['status'] = status
+            data['status'] = status.value
         if side is not None:
             data['side'] = side
         if offset is not None:
@@ -875,7 +970,7 @@ class AsyncHttpApiClient(BaseApiClient):
         if symbol is not None:
             data['symbol'] = symbol
         if side is not None:
-            data['side'] = side
+            data['side'] = side.value
         if quote_asset is not None:
             data['quoteAsset'] = quote_asset
         if buyer_order_id is not None:
@@ -910,11 +1005,11 @@ class AsyncHttpApiClient(BaseApiClient):
         if symbol is not None:
             data['symbol'] = symbol
         if side is not None:
-            data['side'] = side
+            data['side'] = side.value
         if tx_asset is not None:
             data['txAsset'] = tx_asset
         if tx_type is not None:
-            data['txType'] = tx_type
+            data['txType'] = tx_type.value
         if height is not None:
             data['blockHeight'] = height
         if offset is not None:
@@ -928,3 +1023,24 @@ class AsyncHttpApiClient(BaseApiClient):
 
         return await self._get("transactions", data=data)
     get_transactions.__doc__ = HttpApiClient.get_transactions.__doc__
+
+    async def get_block_exchange_fee(
+        self, address: Optional[str] = None, offset: Optional[int] = 0, total: Optional[int] = 0,
+        limit: Optional[int] = 500, start_time: Optional[int] = None, end_time: Optional[int] = None
+    ):
+        data = {}
+        if address is not None:
+            data['address'] = address
+        if offset is not None:
+            data['offset'] = offset
+        if limit is not None:
+            data['limit'] = limit
+        if start_time is not None:
+            data['start'] = start_time
+        if end_time is not None:
+            data['end'] = end_time
+        if total is not None:
+            data['total'] = total
+
+        return await self._get("block-exchange-fee", data=data)
+    get_block_exchange_fee.__doc__ = HttpApiClient.get_block_exchange_fee.__doc__
